(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/common/http'), require('rxjs'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('simple-api-request', ['exports', '@angular/core', '@angular/common', '@angular/common/http', 'rxjs', 'rxjs/operators'], factory) :
    (global = global || self, factory(global['simple-api-request'] = {}, global.ng.core, global.ng.common, global.ng.common.http, global.rxjs, global.rxjs.operators));
}(this, function (exports, core, common, http, rxjs, operators) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
    }

    var ApiRequestService = /** @class */ (function () {
        function ApiRequestService(http) {
            this.http = http;
            this.body = null;
        }
        /**
         * Setting up the base api url
         * @param url The base url
         */
        ApiRequestService.prototype.setUrl = function (url) {
            if (url)
                this.baseUrl = url;
        };
        /**
         * Set the header config for the request
         * @param params Header key and value, must be an object {key:val, ...}
         */
        ApiRequestService.prototype.setHeader = function (params) {
            if (typeof params != "object")
                throw Error('The params provided is not an object type. You provided : ' + params);
            this.headers = { headers: new http.HttpHeaders(params) };
        };
        /**
         * Set the header config for the request
         * @param params Header key and value, must be an object {key:val, ...}
         */
        ApiRequestService.prototype.setBody = function (params) {
            if (typeof params != "object")
                throw Error('The params provided is not an object type. You provided : ' + params);
            this.body = JSON.stringify(params);
        };
        /**
         * Make an api request
         * @param method The request method get or post, default get
         * @param endpoint The api endpoint url
         * @param body The request body
         * @param header The request header
         */
        ApiRequestService.prototype.call = function (method, endpoint, body, header) {
            if (method === void 0) { method = 'get'; }
            if (body)
                this.setBody(body);
            if (header)
                this.setHeader(header);
            return this.http[method](this.baseUrl + ((endpoint) ? endpoint : ""), (this.body) ? this.body : {}, (this.headers) ? this.headers : {}).pipe(operators.catchError(function (e) {
                return rxjs.throwError(e.message || "Failed System");
            }));
        };
        ApiRequestService.ngInjectableDef = core.defineInjectable({ factory: function ApiRequestService_Factory() { return new ApiRequestService(core.inject(http.HttpClient)); }, token: ApiRequestService, providedIn: "root" });
        ApiRequestService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __metadata("design:paramtypes", [http.HttpClient])
        ], ApiRequestService);
        return ApiRequestService;
    }());

    var ApiRequestComponent = /** @class */ (function () {
        function ApiRequestComponent(service) {
            this.service = service;
            this.apiEvent = new core.EventEmitter();
        }
        Object.defineProperty(ApiRequestComponent.prototype, "baseUrl", {
            // once set the base url, init the api service
            set: function (baseUrl) {
                console.log("API::setBaseUrl");
                if (baseUrl) {
                    this.service.setUrl(baseUrl);
                    this.apiEvent.emit("ready");
                }
            },
            enumerable: true,
            configurable: true
        });
        __decorate([
            core.Output(),
            __metadata("design:type", Object)
        ], ApiRequestComponent.prototype, "apiEvent", void 0);
        __decorate([
            core.Input(),
            __metadata("design:type", String),
            __metadata("design:paramtypes", [String])
        ], ApiRequestComponent.prototype, "baseUrl", null);
        ApiRequestComponent = __decorate([
            core.Component({
                selector: 'api-request',
                template: ""
            }),
            __metadata("design:paramtypes", [ApiRequestService])
        ], ApiRequestComponent);
        return ApiRequestComponent;
    }());

    var ApiRequestModule = /** @class */ (function () {
        function ApiRequestModule() {
        }
        ApiRequestModule = __decorate([
            core.NgModule({
                declarations: [ApiRequestComponent],
                imports: [
                    common.CommonModule,
                    http.HttpClientModule
                ],
                providers: [ApiRequestService],
                exports: [ApiRequestComponent]
            })
        ], ApiRequestModule);
        return ApiRequestModule;
    }());

    exports.ApiRequestModule = ApiRequestModule;
    exports.ɵa = ApiRequestComponent;
    exports.ɵb = ApiRequestService;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=simple-api-request.umd.js.map
