import { __decorate, __metadata } from 'tslib';
import { defineInjectable, inject, Injectable, EventEmitter, Output, Input, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { throwError } from 'rxjs';
import { catchError } from 'rxjs/operators';

let ApiRequestService = class ApiRequestService {
    constructor(http) {
        this.http = http;
        this.body = null;
    }
    /**
     * Setting up the base api url
     * @param url The base url
     */
    setUrl(url) {
        if (url)
            this.baseUrl = url;
    }
    /**
     * Set the header config for the request
     * @param params Header key and value, must be an object {key:val, ...}
     */
    setHeader(params) {
        if (typeof params != "object")
            throw Error('The params provided is not an object type. You provided : ' + params);
        this.headers = { headers: new HttpHeaders(params) };
    }
    /**
     * Set the header config for the request
     * @param params Header key and value, must be an object {key:val, ...}
     */
    setBody(params) {
        if (typeof params != "object")
            throw Error('The params provided is not an object type. You provided : ' + params);
        this.body = JSON.stringify(params);
    }
    /**
     * Make an api request
     * @param method The request method get or post, default get
     * @param endpoint The api endpoint url
     * @param body The request body
     * @param header The request header
     */
    call(method = 'get', endpoint, body, header) {
        if (body)
            this.setBody(body);
        if (header)
            this.setHeader(header);
        return this.http[method](this.baseUrl + ((endpoint) ? endpoint : ""), (this.body) ? this.body : {}, (this.headers) ? this.headers : {}).pipe(catchError((e) => {
            return throwError(e.message || "Failed System");
        }));
    }
};
ApiRequestService.ngInjectableDef = defineInjectable({ factory: function ApiRequestService_Factory() { return new ApiRequestService(inject(HttpClient)); }, token: ApiRequestService, providedIn: "root" });
ApiRequestService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [HttpClient])
], ApiRequestService);

let ApiRequestComponent = class ApiRequestComponent {
    constructor(service) {
        this.service = service;
        this.apiEvent = new EventEmitter();
    }
    // once set the base url, init the api service
    set baseUrl(baseUrl) {
        console.log("API::setBaseUrl");
        if (baseUrl) {
            this.service.setUrl(baseUrl);
            this.apiEvent.emit("ready");
        }
    }
};
__decorate([
    Output(),
    __metadata("design:type", Object)
], ApiRequestComponent.prototype, "apiEvent", void 0);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], ApiRequestComponent.prototype, "baseUrl", null);
ApiRequestComponent = __decorate([
    Component({
        selector: 'api-request',
        template: ``
    }),
    __metadata("design:paramtypes", [ApiRequestService])
], ApiRequestComponent);

let ApiRequestModule = class ApiRequestModule {
};
ApiRequestModule = __decorate([
    NgModule({
        declarations: [ApiRequestComponent],
        imports: [
            CommonModule,
            HttpClientModule
        ],
        providers: [ApiRequestService],
        exports: [ApiRequestComponent]
    })
], ApiRequestModule);

export { ApiRequestModule, ApiRequestComponent as ɵa, ApiRequestService as ɵb };
//# sourceMappingURL=simple-api-request.js.map
