import { __decorate, __metadata } from 'tslib';
import { defineInjectable, inject, Injectable, Output, Input, Component, EventEmitter, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { throwError } from 'rxjs';
import { catchError } from 'rxjs/operators';

var ApiRequestService = /** @class */ (function () {
    function ApiRequestService(http) {
        this.http = http;
        this.body = null;
    }
    /**
     * Setting up the base api url
     * @param url The base url
     */
    ApiRequestService.prototype.setUrl = function (url) {
        if (url)
            this.baseUrl = url;
    };
    /**
     * Set the header config for the request
     * @param params Header key and value, must be an object {key:val, ...}
     */
    ApiRequestService.prototype.setHeader = function (params) {
        if (typeof params != "object")
            throw Error('The params provided is not an object type. You provided : ' + params);
        this.headers = { headers: new HttpHeaders(params) };
    };
    /**
     * Set the header config for the request
     * @param params Header key and value, must be an object {key:val, ...}
     */
    ApiRequestService.prototype.setBody = function (params) {
        if (typeof params != "object")
            throw Error('The params provided is not an object type. You provided : ' + params);
        this.body = JSON.stringify(params);
    };
    /**
     * Make an api request
     * @param method The request method get or post, default get
     * @param endpoint The api endpoint url
     * @param body The request body
     * @param header The request header
     */
    ApiRequestService.prototype.call = function (method, endpoint, body, header) {
        if (method === void 0) { method = 'get'; }
        if (body)
            this.setBody(body);
        if (header)
            this.setHeader(header);
        return this.http[method](this.baseUrl + ((endpoint) ? endpoint : ""), (this.body) ? this.body : {}, (this.headers) ? this.headers : {}).pipe(catchError(function (e) {
            return throwError(e.message || "Failed System");
        }));
    };
    ApiRequestService.ngInjectableDef = defineInjectable({ factory: function ApiRequestService_Factory() { return new ApiRequestService(inject(HttpClient)); }, token: ApiRequestService, providedIn: "root" });
    ApiRequestService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [HttpClient])
    ], ApiRequestService);
    return ApiRequestService;
}());

var ApiRequestComponent = /** @class */ (function () {
    function ApiRequestComponent(service) {
        this.service = service;
        this.apiEvent = new EventEmitter();
    }
    Object.defineProperty(ApiRequestComponent.prototype, "baseUrl", {
        // once set the base url, init the api service
        set: function (baseUrl) {
            console.log("API::setBaseUrl");
            if (baseUrl) {
                this.service.setUrl(baseUrl);
                this.apiEvent.emit("ready");
            }
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ApiRequestComponent.prototype, "apiEvent", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String),
        __metadata("design:paramtypes", [String])
    ], ApiRequestComponent.prototype, "baseUrl", null);
    ApiRequestComponent = __decorate([
        Component({
            selector: 'api-request',
            template: ""
        }),
        __metadata("design:paramtypes", [ApiRequestService])
    ], ApiRequestComponent);
    return ApiRequestComponent;
}());

var ApiRequestModule = /** @class */ (function () {
    function ApiRequestModule() {
    }
    ApiRequestModule = __decorate([
        NgModule({
            declarations: [ApiRequestComponent],
            imports: [
                CommonModule,
                HttpClientModule
            ],
            providers: [ApiRequestService],
            exports: [ApiRequestComponent]
        })
    ], ApiRequestModule);
    return ApiRequestModule;
}());

export { ApiRequestModule, ApiRequestComponent as ɵa, ApiRequestService as ɵb };
//# sourceMappingURL=simple-api-request.js.map
